//src\App.tsx
import { useState, useEffect, useMemo } from "react";
import AnalogClock from "./components/AnalogClock";
import CalendarGrid from "./components/CalendarGrid";
import WeatherSection from "./components/WeatherSection";
import NewsSection from "./components/NewsSection";
import { generateCalendarDays } from "./utils/calendar";
import { NewsItem } from "./types/magic-mirror";
import VoiceAssistant from "./components/VoiceAssistant";
import useSWR from "swr";

const MagicMirror = () => {
  const [time, setTime] = useState(new Date());
  const calendarDays = useMemo(() => generateCalendarDays(), []);

  // 新闻数据
  const { data } = useSWR<NewsItem[]>(
    "news",
    async () => {
      try {
        return await window.electronAPI.getNews();
      } catch (error) {
        console.error("新闻加载失败:", error);
        throw error;
      }
    },
    {
      refreshInterval: 600000,
      onErrorRetry: (error) => {
        if (error.message.includes("500")) return; // 服务器错误不重试
      },
    }
  );

  // 天气数据

  // 更新时间
  useEffect(() => {
    const timer = setInterval(() => setTime(new Date()), 1000);
    return () => clearInterval(timer);
  }, []);

  // 生成问候语
  const greeting = useMemo(() => {
    const hours = time.getHours();
    if (hours < 5) return "夜深了";
    if (hours < 12) return "早上好";
    if (hours < 18) return "下午好";
    return "晚上好";
  }, [time]);

  return (
    <div className="min-h-screen bg-black text-gray-100 font-sans antialiased overflow-hidden">
      {/* 时间模块 */}
      <div className="absolute top-8 left-8 flex items-start gap-8">
        <div className="space-y-1">
          <div className="text-2xl font-light">
            {time.toLocaleDateString("zh-CN", { weekday: "long" })}
          </div>
          <div className="text-gray-400 text-sm">
            {time.toLocaleDateString("zh-CN", {
              year: "numeric",
              month: "long",
              day: "numeric",
            })}
          </div>
          <div className="flex items-end gap-2">
            <div className="text-5xl font-light">
              {time.toLocaleTimeString("zh-CN", {
                hour: "2-digit",
                minute: "2-digit",
                hour12: false,
              })}
            </div>
            <div className="text-gray-400 mb-5">
              {time.getSeconds().toString().padStart(2, "0")}
            </div>
          </div>
        </div>
        <AnalogClock time={time} />
      </div>

      {/* 日历模块 */}
      <div className="absolute top-48 left-8 w-64">
        <div className="mb-4 text-gray-300 text-sm">
          {time.toLocaleDateString("zh-CN", { month: "long", year: "numeric" })}
        </div>
        <CalendarGrid days={calendarDays} />
      </div>

      {/* 其他模块 */}
      <WeatherSection />
      <NewsSection items={data || []} />
      <VoiceAssistant greeting={greeting} />
    </div>
  );
};

export default MagicMirror;
